@@ -114,7 +114,9 @@ observe({
             mod_plotMap <- plotMap(list_data_all$antaresDataList[ind_map], ml, 
                                    interactive = TRUE, .updateBtn = TRUE, 
                                    .updateBtnInit = TRUE, compare = .compare,
-                                   language = language, 
+                                   language = language,
+                                   #export with webshot dont work with leaflet and mapLayout
+                                   .exportBtn = FALSE,
                                    h5requestFiltering = list_data_all$params[ind_map],
                                    xyCompare = "union", .runApp = FALSE)
             
